// *************************************************************************************************
// 		  Competition, cooperation, and collective choice
// *************************************************************************************************
// To run this do-file, you need the file PGvotecompete.dta

// *** Basic descriptive statitics ***
use PGvotecompete, clear
bys voterule: tabstat contribute, by(rule)
tab biggroup rule, sum(contribute) nofreq nost

// *** Figure 1 ***
use PGvotecompete, clear
gen cont1 = contribute if rule==1
gen cont0 = contribute if rule==0
gen rule1 = 1 if rule==1 & thisperiod==1 & id==1 & idgroup==1
gen rule0 = 1 if rule==0 & thisperiod==1 & id==1 & idgroup==1
collapse cont1 cont0 (count) nobs1=cont1 nobs0=cont0 (sum) rule1 rule0 (sem) cont_se1=cont1 cont_se0=cont0, by(voterule part)
gen id = voterule*10 + part
gen percent1 = rule1 / (rule1 + rule0)
gen percent0 = rule0 / (rule1 + rule0)
reshape long cont cont_se rule nobs percent, i(id) j(compete)
gen cont_ll = cont - cont_se * invttail(nobs, 0.025)
gen cont_ul = cont + cont_se * invttail(nobs, 0.025)
replace percent = round(percent * 100, 1)
gen xvar = part + (compete - 0.5) * 0.41
gen ylabel = 2
replace xvar = 2.4 + part + (compete - 0.5) * 0.41 if voterule==1
replace xvar = 5.8 + part + (compete - 0.5) * 0.41 if voterule==2
replace ylabel = .
graph set window fontface "Times"
twoway (bar cont xvar if compete==0, fcolor(erose) lcolor(black) barwidth(0.4)) (bar cont xvar if compete==1, fcolor(edkblue) lcolor(black) barwidth(0.4)) (scatter ylabel xvar, msize(ehuge) msymbol(smsquare) mlabel(percent) mlabsize(medlarge) mlabcolor(black) mlabposition(0) mfcolor(white) mlcolor("80 0 0")), ytitle(Mean contribution, size(medlarge) margin(bottom)) yscale(noline) ylabel(0(5)29, labsize(medium) angle(horizontal) nogrid) xtitle("") xscale(range(0.47 9.35)) xscale(noline) xline(2.7 6.1, lwidth(medium) lcolor(black)) xlabel(1 "Phase 1" 2 "Phase 2" 3.4 "Phase 1" 4.4 "Phase 2" 5.4 "Phase 3" 6.8 "Phase 1" 7.8 "Phase 2" 8.8 "Phase 3", labsize(medlarge)) text(32 1.5 "No voting", place(c) size(vlarge)) text(32 4.4 "Majority", place(c) size(vlarge)) text(32 7.8 "Group veto", place(c) size(vlarge)) legend(order(1 "No competition" 2 "Competition" 3 "Percentage of organisations") rows(1) size(medlarge) region(fcolor(white) margin(zero) lcolor(white)) bmargin(top) position(6) span symxsize(10) keygap(1.5)) name(contributions, replace) xsize(10) ysize(5) graphregion(margin(1 1 0 8) fcolor(white) lcolor(white)) plotregion(margin(bargraph) lcolor(black)) text(2 0.795 "50", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 1.205 "50", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 1.795 "50", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 2.205 "50", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 3.195 "17", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 3.605 "83", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 4.195 "0", box size(large) margin(2 2 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 4.605 "100", box size(large) margin(0 0 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 5.195 "0", box size(large) margin(2 2 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 5.605 "100", box size(large) margin(0 0 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 6.595 "43", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 7.005 "57", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 7.595 "71", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 8.005 "29", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 8.595 "43", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium)) text(2 9.005 "57", box size(large) margin(1 1 1 1) fcolor(white) lcolor("80 0 0") lwidth(medium))
graph export contributionsnosd.eps, as(eps) replace  logo(off) cmyk(off) preview(off) fontface(Times)

// *** Table A1 ***
use PGvotecompete, clear
gen cont1 = contribute if rule==1
gen cont0 = contribute if rule==0
tabstat contribute cont1 cont0 rule vote if part==1, by(voterule) s(me sd)
tabstat contribute cont1 cont0 rule vote if part==2, by(voterule) s(me sd)
tabstat contribute cont1 cont0 rule vote if part==3, by(voterule) s(me sd)
tabstat contribute cont1 cont0 rule vote if part<=3, by(voterule) s(me sd)

// *** Table A2 ***
use PGvotecompete, clear
gen cont1 = contribute if rule==1
gen cont0 = contribute if rule==0
tabstat contribute cont1 cont0 rule vote if part==3 & voterule==1, by(treatment) s(me sd)

// *** Figure A1 ***
use PGvotecompete, clear
collapse contribute rule if part <= 3, by(treatment part biggroup smallgroup)
egen rnk = rank(smallgroup) if part == 1, by(biggroup)
egen groupid = mean(rnk), by(smallgroup)
egen rnk2 = rank(biggroup) if part == 1 & groupid==1, by(treatment)
egen biggroupid = mean(rnk2), by(biggroup)
la def treatlbl 0 "NV" 1 "M" 2 "GV", modify
graph set window fontface "Times"
twoway (line contribute part if groupid==3, lcolor(black) lwidth(thin)) (line contribute part if groupid==1, lcolor(black) lwidth(thin)) (line contribute part if groupid==2, lcolor(black) lwidth(thin)) (scatter contribute part if rule==0, msize(vlarge) msymbol(circle) mfcolor(erose) mlcolor(black) mlwidth(medium)) (scatter contribute part if rule==1, msize(vlarge) msymbol(circle) mfcolor(edkblue) mlcolor(black) mlwidth(medium)) if part <= 3, ytitle(Mean contribution) ytitle(, size(medlarge)) yscale(noline) ylabel(0(5)30, labsize(medium) angle(horizontal) nogrid) xtitle("") xscale(range(0.5 3.5)) xscale(noline) xlabel(1 "Phase 1" 2 "Phase 2" 3 "Phase 3", labsize(large)) by(, note("")) by(, legend(position(6) span)) legend(order(4 "No competition" 5 "Competition") rows(1) size(medlarge) region(fcolor(white) lcolor(white))) name(smallgroupcont, replace) xsize(10) ysize(5) by(, graphregion(margin(tiny) fcolor(white) lcolor(white))) by(treatment biggroupid, cols(7) hol(7 14)) subtitle(, size(vlarge) nobox) plotregion(margin(tiny) lcolor(black))
graph export smallgroupcont.eps, as(eps) replace  logo(off) cmyk(off) preview(off) fontface(Times)

// *** Table 2 ***
use PGvotecompete, clear

xtreg contribute i.voterule i.rule#i.voterule if part <= 3, cluster(biggroup) re
test 1.rule#0.voterule = 1.rule#1.voterule
test 1.rule#0.voterule = 1.rule#2.voterule
test 1.rule#1.voterule = 1.rule#2.voterule
test (1.rule#0.voterule = 1.rule#1.voterule) (1.rule#0.voterule = 1.rule#2.voterule) (1.rule#1.voterule = 1.rule#2.voterule)

xtreg contribute i.voterule i.rule#i.voterule i.period#i.voterule if part <= 3, cluster(biggroup) fe
test 1.rule#0.voterule = 1.rule#1.voterule
test 1.rule#0.voterule = 1.rule#2.voterule
test (1.rule#0.voterule = 1.rule#1.voterule) (1.rule#0.voterule = 1.rule#2.voterule)

reg contribute i.voterule i.rule#i.voterule if period==1, cluster(biggroup)
test 1.rule#0.voterule = 1.rule#1.voterule
test 1.rule#0.voterule = 1.rule#2.voterule
test (1.rule#0.voterule = 1.rule#1.voterule) (1.rule#0.voterule = 1.rule#2.voterule)

// Effect of voting preferences (footnote 19)
replace vote = 0 if voterule == 0
xtreg contribute i.rule#i.voterule#i.vote if part <= 3, cluster(biggroup) re
test 1.rule#0.voterule#0.vote = 1.rule#1.voterule#1.vote
test 1.rule#0.voterule#0.vote = 1.rule#1.voterule#2.vote
test 1.rule#0.voterule#0.vote = 1.rule#2.voterule#1.vote
test 1.rule#0.voterule#0.vote = 1.rule#2.voterule#2.vote

xtreg contribute 0.rule#0.vote 1.rule#0.vote 1.rule#1.vote 1.rule#2.vote 1.rule#1.vote#2.voterule i.period#i.voterule if part <= 3, cluster(biggroup) fe
test 1.rule#0.vote = 1.rule#1.vote
test 1.rule#0.vote = 1.rule#2.vote
test 1.rule#0.vote = 1.rule#1.vote + 1.rule#1.vote#2.voterule
test 1.rule#0.vote = 1.rule#2.vote + 1.rule#2.vote#2.voterule

reg contribute i.rule#i.voterule#i.vote if period==1, cluster(biggroup)
test 1.rule#0.voterule#0.vote = 1.rule#1.voterule#1.vote
test 1.rule#0.voterule#0.vote = 1.rule#1.voterule#2.vote
test 1.rule#0.voterule#0.vote = 1.rule#2.voterule#1.vote
test 1.rule#0.voterule#0.vote = 1.rule#2.voterule#2.vote

// *** Table A4 ***
use PGvotecompete, clear
collapse contribute if part < 3 & treatment==0, by(biggroup rule)
ranksum contribute, by(rule)
reshape wide contribute, i(biggroup) j(rule)
signrank contribute0 = contribute1
use PGvotecompete, clear
collapse contribute if period == 1 & treatment==0, by(biggroup rule)
ranksum contribute, by(rule)
use PGvotecompete, clear
collapse contribute if part <= 3 & treatment>0, by(biggroup rule)
ranksum contribute, by(rule)
reshape wide contribute, i(biggroup) j(rule)
signrank contribute0 = contribute1
use PGvotecompete, clear
collapse contribute if period == 1 & treatment>0, by(biggroup rule)
ranksum contribute, by(rule)
use PGvotecompete, clear
gen exog = voterule == 0
replace exog = . if part == 3 & treatment == 0
collapse contribute if part <= 3, by(biggroup exog rule)
ranksum contribute if rule==0, by(exog)
ranksum contribute if rule==1, by(exog)
use PGvotecompete, clear
collapse contribute if treatment==0 & rule==1, by(biggroup voterule)
reshape wide contribute, i(biggroup) j(voterule)
signrank contribute0 = contribute1
use PGvotecompete, clear
gen exog = voterule == 0
replace exog = . if part == 3 & treatment == 0
collapse contribute if period == 1, by(biggroup exog rule)
ranksum contribute if rule==0, by(exog)
ranksum contribute if rule==1, by(exog)

// *** Figure 2 ***
use PGvotecompete, clear
collapse contribute, by(rule part subject)
tabstat contribute, by(rule)
replace contribute = round(contribute, 2)
contract contribute rule, zero
egen conttot = sum(_freq), by(rule)
gen contper = 100 * _freq / conttot
gen xvar = contribute
local barw = 1
replace xvar = contribute + 0.625 * `barw' * (rule - 0.5)
twoway (bar contper xvar if rule==0, sort fcolor(erose) lcolor(black) barwidth(`barw')) (bar contper xvar if rule==1, sort fcolor(edkblue) lcolor(black) barwidth(`barw')) (lowess contper contribute if rule==0, mean adjust bwidth(0.5) lcolor(erose) lwidth(thick) lpattern(dash)) (lowess contper contribute if rule==1, mean adjust bwidth(0.5) lcolor(edkblue) lwidth(thick) lpattern(dash)), ytitle(Percent, size(medlarge)) yscale(noline) ylabel(0(5)25, labsize(medium) angle(horizontal) nogrid) xtitle(Mean contribution per phase, size(medlarge) margin(top)) xscale(noline) xlabel(0(5)30, labsize(medium)) legend(order(1 "No competition" 2 "Competition") symxsize(10) cols(1) size(medlarge) region(fcolor(none) lcolor(none)) position(11) ring(0)) name(contdist, replace) xsize(5) ysize(5) graphregion(margin(tiny) fcolor(white) lcolor(white)) plotregion(margin(bargraph) lcolor(black)) nodraw
clear
clear matrix
set memory 200M
set obs 1000000
gen biggroup = ceil((_n-0.5)/8)
gen g1 = runiform()
gen g2 = runiform()
gen g3 = runiform()
gen id = _n
reshape long g, i(id) j(smallgroup)
egen win = rank(g), by(id) unique
replace win = 10 * (2 - win)
replace smallgroup = biggroup * 10 + smallgroup
collapse win, by(smallgroup)
save transfer.dta, replace
use PGvotecompete, clear
drop win
gen prize = 10 * (2 - rank)
egen win = mean(prize), by(rule subject part)
replace smallgroup = -subject
collapse win if thisperiod == 1, by(rule smallgroup)
append using transfer.dta
replace rule = 2 if rule==.
replace win = min(10, round(win, 1.25))
contract win rule, zero
egen wintot = sum(_freq), by(rule)
gen winper = 100 * _freq / wintot
gen xvar = win
local barw = 0.625
replace xvar = win + 0.625 * `barw' * (rule - 1.5)
twoway (bar winper xvar if rule==2, sort fcolor(eltgreen) lcolor(black) barwidth(`barw')) (bar winper xvar if rule==1, sort fcolor(edkblue) lcolor(black) barwidth(`barw')) (lowess winper win if rule==2, mean adjust bwidth(0.3) lcolor(eltgreen) lwidth(thick) lpattern(dash)) (lowess winper win if rule==1, mean adjust bwidth(0.5) lcolor(edkblue) lwidth(thick) lpattern(dash)), ytitle(Percent, size(medlarge)) yscale(noline) ylabel(0(5)20, labsize(medium) angle(horizontal) nogrid) xtitle(Mean transfer per phase, size(medlarge) margin(top)) xscale(noline) xlabel(-10(5)10, labsize(medium)) legend(order(2 "Competition" 1 "Predicted if everyone's probability of" 0 "winning is 1/3") symxsize(10) cols(1) size(medlarge) region(fcolor(none) lcolor(none)) position(11) ring(0)) name(windist, replace) xsize(5) ysize(5) graphregion(margin(tiny) fcolor(white) lcolor(white)) plotregion(margin(bargraph) lcolor(black)) nodraw
graph set window fontface "Times"
graph combine contdist windist, rows(1) iscale(*1.35) name(conttransfer, replace) xsize(10) ysize(5) imargin(small) graphregion(margin(0 0 0 0) fcolor(white) lcolor(white))
graph export conttransfer.eps, as(eps) replace  logo(off) cmyk(off) preview(off) fontface(Times)
erase transfer.dta

// *** Figure 3 ***
use PGvotecompete, clear
replace voterule = voterule > 0
collapse rank rule, by(voterule part smallgroup thisperiod)
gen id = smallgroup * 10 + part
xtset id thisperiod
gen Lrank = L.rank
bysort rule: tab Lrank rank, co
collapse rank (sem) rankse=rank (count) nobs=rank if Lrank<., by(voterule rule Lrank)
gen rank_ll = rank - rankse * invttail(nobs, 0.025)
gen rank_ul = rank + rankse * invttail(nobs, 0.025)
replace Lrank = Lrank + 0.05 * (voterule - 0.5)
twoway (line rank Lrank if voterule==1, sort lcolor(edkblue) lwidth(vthick)) (line rank Lrank if voterule==0, sort lcolor(erose) lwidth(vthick)) (scatter rank Lrank if voterule==1, sort mcolor(edkblue) msize(vlarge) msymbol(diamond)) (scatter rank Lrank if voterule==0, sort mcolor(erose) msize(vlarge) msymbol(diamond)) if rule==1, ytitle(Mean rank in current period, size(vlarge) margin(zero)) yscale(noline) ylabel(1(1)3.2, labsize(large) angle(horizontal) nogrid) xtitle(Rank in previous period, size(vlarge) margin(top)) xscale(noline) xlabel(1(1)3, labsize(large)) title(Competition, size(huge) color(black) position(12)) legend(order(1 "Voting" 2 "No voting") cols(1) size(vlarge) region(fcolor(none) lcolor(none)) position(11) ring(0)) name(rankperiodcomp, replace) xsize(4) ysize(6) graphregion(margin(left) fcolor(white) lcolor(white)) plotregion(margin(large) lcolor(black)) nodraw
twoway (line rank Lrank if voterule==1, sort lcolor(edkblue) lwidth(vthick)) (line rank Lrank if voterule==0, sort lcolor(erose) lwidth(vthick)) (scatter rank Lrank if voterule==1, sort mcolor(edkblue) msize(vlarge) msymbol(diamond)) (scatter rank Lrank if voterule==0, sort mcolor(erose) msize(vlarge) msymbol(diamond)) if rule==0, ytitle(Mean rank in current period, size(vlarge) margin(zero)) yscale(noline) ylabel(1(1)3.2, labsize(large) angle(horizontal) nogrid) xtitle(Rank in previous period, size(vlarge) margin(top)) xscale(noline) xlabel(1(1)3, labsize(large)) title(No competition, size(huge) color(black) position(12)) legend(order(1 "Voting" 2 "No voting") cols(1) size(vlarge) region(fcolor(none) lcolor(none)) position(11) ring(0)) name(rankperiodnocomp, replace) xsize(4) ysize(6) graphregion(margin(left) fcolor(white) lcolor(white)) plotregion(margin(large) lcolor(black)) nodraw
use PGvotecompete, clear
collapse rank win, by(voterule rule part biggroup smallgroup)
xtset smallgroup part
gen Lrank = L.rank
gen Lrule = L.rule
gen Lrank1 = Lrank if Lrule==1
gen Lrank0 = Lrank if Lrule==0
keep if rule==1 & Lrank < .
collapse rank Lrank*, by(smallgroup)
twoway (scatter rank Lrank1, sort mcolor(edkblue) msize(medium) msymbol(diamond)) (scatter rank Lrank0, sort mcolor(erose) msize(medium) msymbol(diamond)) (lfit rank Lrank1, lcolor(erose) lwidth(vthick)) (lfit rank Lrank0, lcolor(edkblue) lwidth(vthick)), ytitle(Mean rank in current phase, size(vlarge) margin(zero)) yscale(noline) ylabel(1(1)3.2, labsize(large) angle(horizontal) nogrid) xtitle(Mean rank in previous phase, size(vlarge) margin(top)) xscale(noline) xlabel(1(1)3, labsize(large)) title(Competition, size(huge) color(black) position(12)) legend(order(3 "Competition" 4 "No competition") cols(1) size(vlarge) region(fcolor(none) lcolor(none) margin(top_bottom)) bmargin(zero) title(Played previous phase with:, size(vlarge) color(black)) position(11) ring(0)) name(rankpart, replace) xsize(4) ysize(6) graphregion(margin(left) fcolor(white) lcolor(white)) plotregion(margin(large) lcolor(black)) nodraw
graph set window fontface "Times"
graph combine rankperiodcomp rankperiodnocomp rankpart, rows(1) iscale(*0.95) name(ranks, replace) xsize(12) ysize(6) imargin(3 2 0 0) graphregion(margin(0 0 0 0) fcolor(white) lcolor(white))

// *** Persistence of winning, Table A5 (and footnote 22) ***
use PGvotecompete, clear
collapse rank win if part<=3, by(treatment voterule part rule biggroup smallgroup thisperiod)
gen id = smallgroup * 10 + part
xtset id thisperiod
gen Lrank = L.rank
oprobit rank Lrank if rule==1 & voterule>0, cluster(biggroup) nolog
oprobit rank Lrank if rule==0 & voterule>0, cluster(biggroup) nolog
oprobit rank Lrank if rule==1 & voterule==0, cluster(biggroup) nolog
oprobit rank Lrank if rule==0 & voterule==0, cluster(biggroup) nolog
use PGvotecompete, clear
collapse rank contribute, by(treatment voterule rule part biggroup smallgroup)
xtset smallgroup part
gen Lrank = L.rank - 2
gen Lrule = L.rule
reg rank Lrank 1.Lrule#c.Lrank if rule==1, cluster(biggroup)
reg rank Lrank 1.Lrule#c.Lrank if rule==0, cluster(biggroup)
// Appendix footnote
egen rankall = rank(contribute), by(biggroup part)
gen Lrankall = L.rankall
bys part: spearman rankall Lrankall

// *** Descriptive statitics of voting and implementation of competition ***
use PGvotecompete, clear
keep if (period == 1 | period == 9 | period == 17) & vote < .
tabstat vote rule, by(voterule) s(me sd)

// *** Tests for differences in voting and implementation ***
use PGvotecompete, clear
keep if thisperiod == 1 & vote < . & part <= 3
replace vote = vote - 1
egen votesg = sum(vote), by(smallgroup part)
egen voterose = sum(vote), by(biggroup part)
egen minvotesg = min(votesg), by(biggroup part)
gen ruleM = voterose >= 5
gen ruleV = minvotesg >= 2
// Difference in implementation (footnote 23)
probit rule i.voterule if id==0 & idgroup==0, nolog cluster(biggroup)
// Difference in voting
xi: gllamm vote i.voterule, i(subject) fam(binom) link(probit) adapt cluster(biggroup)
// Footnote 25
probit ruleM i.voterule if id==0 & idgroup==0, nolog cluster(biggroup)
probit ruleV i.voterule if id==0 & idgroup==0, nolog cluster(biggroup)

// *** Non-parametric tests for differences in voting and implementation ***
collapse vote rule ruleM ruleV if part <= 3, by(biggroup treatment voterule)
ranksum vote, by(voterule)
ranksum rule, by(voterule)
ranksum ruleM, by(voterule)
ranksum ruleV, by(voterule)

// *** Figure 4 ***
use PGvotecompete, clear
keep if thisperiod == 1 & vote < . & part <= 3
replace vote = vote - 1
egen votesg = sum(vote), by(smallgroup part)
egen voterose = sum(vote), by(biggroup part)
egen minvotesg = min(votesg), by(biggroup part)
ren vote vote0
gen vote1 = voterose >= 5 if thisperiod==1 & id==1 & idgroup==1
gen vote2 = minvotesg >= 2 if thisperiod==1 & id==1 & idgroup==1
forvalues i=0(1)2 {
	ci vote`i' if voterule==1, binomial
	gen vote_ll`i' = r(lb) if voterule==1
	gen vote_ul`i' = r(ub) if voterule==1
	ci vote`i' if voterule==2, binomial
	replace vote_ll`i' = r(lb) if voterule==2
	replace vote_ul`i' = r(ub) if voterule==2
}
collapse vote0 vote1 vote2 vote_*, by(voterule)
gen id = _n
reshape long vote vote_ll vote_ul, j(type) i(id)
la def typelbl 0 "Votes for competition" 1 "Majority rule" 2 "Group veto rule"
la val type typelbl
graph set window fontface "Times"
twoway (bar vote voterule if voterule==1, fcolor(erose) lcolor(black) barwidth(0.75)) (bar vote voterule if voterule==2, fcolor(edkblue) lcolor(black) barwidth(0.75)), ytitle(Fraction) ytitle(, size(large)) yscale(noline) ylabel(0(0.2)0.95, labsize(medlarge) angle(horizontal) format(%9.1f) nogrid) xtitle("") xscale(range(0.15 2.85)) xscale(noline) xlabel(none, labsize(vlarge)) by(, title(Organisations implementing competition if they use the, size(large) color(black) position(12) margin(73 0 0 0)) note("")) by(, legend(position(6))) legend(order(0 "Actual rule used:" 1 "Majority" 2 "Group veto") rows(1) size(large) region(fcolor(white) lcolor(white))) name(voterules, replace) xsize(10) ysize(5) by(, graphregion(margin(tiny) fcolor(white) lcolor(white))) by(type, rows(1)) subtitle(, size(vlarge) nobox) plotregion(margin(bargraph) lcolor(black))
graph export voterulesnosd.eps, as(eps) replace  logo(off) cmyk(off) preview(off) fontface(Times)

// *** Figure 5 ***
use PGvotecompete, clear
egen conta = mean(contribute) if treatment>=0 & rule==1, by(subject part)
egen contb = mean(contribute) if treatment>=0 & rule==0, by(subject part)
collapse expmya expmyb conta contb expothera expotherb if thisperiod == 1, by(treatment subject)
gen diffcont0 = expmya - expmyb
gen diffcont2 = expothera - expotherb
gen diffcont1 = conta - contb
reshape long diffcont, i(subject) j(exptype)
tabstat diffcont, by(exptype)
replace diffcont = 29 if diffcont == 30
replace diffcont = round(diffcont-1.5, 3)+1.5
drop if diffcont == .
contract diffcont exptype, zero
egen difftot = sum(_freq), by(exptype)
gen diffper = 100 * _freq / difftot
gen xvar = diffcont
local barw = 1.5
replace xvar = diffcont + 0.625 * `barw' * (exptype - 0.5)
twoway (bar diffper xvar if exptype==0, sort fcolor(erose) lcolor(black) barwidth(`barw')) (bar diffper xvar if exptype==1, sort fcolor(edkblue) lcolor(black) barwidth(`barw')) (lowess diffper diffcont if exptype==0, mean adjust bwidth(0.5) lcolor(erose) lwidth(thick) lpattern(dash)) (lowess diffper diffcont if exptype==1, mean adjust bwidth(0.5) lcolor(edkblue) lwidth(thick) lpattern(dash)), ytitle(Percent, size(medlarge)) yscale(noline) ylabel(0(5)30, labsize(medium) angle(horizontal) nogrid) xtitle("Mean difference in contributions between" "competition and no competition", size(medlarge) margin(top)) xscale(noline) xlabel(-10(5)30, labsize(medium)) legend(order(1 "Expected" 2 "Observed") rows(1) size(medlarge) region(fcolor(none) lcolor(none)) position(12) ring(0)) name(expcontdist, replace) xsize(5) ysize(5) graphregion(margin(tiny) fcolor(white) lcolor(white)) plotregion(margin(bargraph) lcolor(black)) nodraw
use PGvotecompete, clear
egen prize1 = mean(win) if rule==1, by(subject part)
collapse prize2=expprize prize1 if thisperiod == 1, by(subject)
reshape long prize, i(subject) j(exptype)
tabstat prize, by(exptype)
replace prize = min(10, round(prize, 1.25))
drop if prize==.
contract prize exptype, zero
egen prizetot = sum(_freq), by(exptype)
gen prizeper = 100 * _freq / prizetot
gen xvar = prize
local barw = 0.625
replace xvar = prize + 0.625 * `barw' * (exptype - 1.5)
twoway (bar prizeper xvar if exptype==2, sort fcolor(erose) lcolor(black) barwidth(`barw')) (bar prizeper xvar if exptype==1, sort fcolor(edkblue) lcolor(black) barwidth(`barw')) (lowess prizeper prize if exptype==2, mean adjust bwidth(0.5) lcolor(erose) lwidth(thick) lpattern(dash)) (lowess prizeper prize if exptype==1, mean adjust bwidth(0.5) lcolor(edkblue) lwidth(thick) lpattern(dash)), ytitle(Percent, size(medlarge)) yscale(noline) ylabel(0(5)20, labsize(medium) angle(horizontal) nogrid) xtitle("Mean transfer per phase" " ", size(medlarge) margin(top)) xscale(noline) xlabel(-10(5)10, labsize(medium)) legend(order(1 "Expected" 2 "Observed") rows(1) size(medlarge) region(fcolor(none) lcolor(none)) position(12) ring(0)) name(expwindist, replace) xsize(5) ysize(5) graphregion(margin(tiny) fcolor(white) lcolor(white)) plotregion(margin(bargraph) lcolor(black)) nodraw
graph set window fontface "Times"
graph combine expcontdist expwindist, rows(1) iscale(*1.4) name(expcontwindist, replace) xsize(10) ysize(5) imargin(small) graphregion(margin(0 0 0 0) fcolor(white) lcolor(white))
graph export expcontwindist.eps, as(eps) replace  logo(off) cmyk(off) preview(off) fontface(Times)

// *** Descriptive statistics of expectations and voting (Table A3) ***
use PGvotecompete, clear
egen conta = mean(contribute) if rule==1, by(smallgroup part)
egen contb = mean(contribute) if rule==0, by(smallgroup part)
keep if thisperiod == 1
gen diffexpmy = expmya - expmyb
gen diffexpother = expothera - expotherb
gen diffmyothera = expmya - expothera
gen diffmyotherb = expmyb - expotherb

bysort part: tabstat expmyb expmya expotherb expothera expprize, by(voterule) s(me sd)
tabstat expmyb expmya expotherb expothera expprize, by(voterule) s(me sd)

// No difference between the majority and group veto rules
collapse expmyb expmya expotherb expothera expprize if voterule > 0, by(voterule biggroup)
ranksum expmyb, by(voterule)
ranksum expmya, by(voterule)
ranksum expotherb, by(voterule)
ranksum expothera, by(voterule)
ranksum expprize, by(voterule)

// Parametric tests for expectations
use PGvotecompete, clear
gen conta = contribute if rule==1
gen contb = contribute if rule==0
egen contavga = mean(conta), by(part)
egen contavgb = mean(contb), by(part)
egen prize = mean(win) if rule==1, by(subject part)
keep if thisperiod == 1

gen diffexpmy = expmya - expmyb
gen diffexpother = expothera - expotherb
xtreg diffexpmy i.part, cluster(biggroup) re
test _cons + 2.part = 0
test _cons + 3.part = 0
xtreg diffexpother i.part, cluster(biggroup) re
test _cons + 2.part = 0
test _cons + 3.part = 0

gen accuracydiffmy = (contavga - contavgb) - diffexpmy
gen accuracydiffother = (contavga - contavgb) - diffexpother
xtreg accuracydiffmy ib3.part, cluster(biggroup)
test _cons + 1.part=0
test _cons + 2.part=0
xtreg accuracydiffother ib3.part, cluster(biggroup)
test _cons + 1.part=0
test _cons + 2.part=0

xtreg expprize ib3.part, cluster(biggroup) re
test 2.part + _cons = 0

gen accuracyprize = expprize - prize if rule==1
xtreg accuracyprize ib3.part, cluster(biggroup)
test 2.part + _cons = 0

collapse accur* cont* diff* exp*, by(treatment biggroup subject)
spearman diffexpmy expprize

// Non-parametric tests for expectations
collapse accur* cont* diff* exp*, by(treatment biggroup)
signrank diffexpmy = 0
signrank diffexpother = 0
signrank accuracydiffmy = 0
signrank accuracydiffother = 0
signrank expprize = 0
signrank accuracyprize = 0

// Ksmirnov tests 
use PGvotecompete, clear
egen prize1 = mean(win) if rule==1, by(subject part)
collapse prize2=expprize prize1 if thisperiod == 1, by(subject)
reshape long prize, i(subject) j(exptype)
ksmirnov prize, by(exptype) e
use PGvotecompete, clear
egen conta = mean(contribute) if treatment>=0 & rule==1, by(subject part)
egen contb = mean(contribute) if treatment>=0 & rule==0, by(subject part)
collapse expmya expmyb conta contb if thisperiod == 1, by(treatment subject)
gen diffcont0 = expmya - expmyb
gen diffcont1 = conta - contb
reshape long diffcont, i(subject) j(exptype)
ksmirnov diffcont, by(exptype) e

// *** Expectations and voting (Table 3) ***
use PGvotecompete, clear
keep if thisperiod == 1 & vote < .
gen diffexpmy = expmya - expmyb
gen diffexpother = expothera - expotherb
xtset subject part
xi i.part*i.voterule, prefix(I)
replace lottery = 1 - lottery
replace vote = vote - 1

gllamm vote expprize diffexpmy Ipart_2 Ipart_3 Ivoterule_2 IparXvot_2_2 IparXvot_3_2, i(subject) fam(binom) link(probit) adapt cluster(biggroup) nolog
test expprize = 2 * diffexpmy
matrix a=e(b) 
quietly xtprobit vote expprize diffexpmy Ipart_2 Ipart_3 Ivoterule_2 IparXvot_2_2 IparXvot_3_2, nolog re i(subject) from(a,copy) intpoints(30) iterate(0) 
mfx compute, predict(pu0)

gllamm vote expprize diffexpmy gender lottery Ipart_2 Ipart_3 Ivoterule_2 IparXvot_2_2 IparXvot_3_2, i(subject) fam(binom) link(probit) adapt cluster(biggroup) nolog
test expprize = 2 * diffexpmy
matrix a=e(b) 
quietly xtprobit vote expprize diffexpmy gender lottery Ipart_2 Ipart_3 Ivoterule_2 IparXvot_2_2 IparXvot_3_2, nolog re i(subject) from(a,copy) intpoints(30) iterate(0) 
mfx compute, predict(pu0)

// Footnote 32
gen e = gender
xi i.e*expprize i.e*diffexpmy i.e*lottery, prefix(G) noomit
gllamm vote gender expprize diffexpmy lottery GeXexppr_1 GeXdiffe_1 GeXlotte_1 Ipart_2 Ipart_3 Ivoterule_2 IparXvot_2_2 IparXvot_3_2, i(subject) fam(binom) link(probit) adapt cluster(biggroup) nolog

// Gender and contributions (footnote 31)
use PGvotecompete, clear
xtreg contribute 1.gender 1.rule#i.voterule 1.gender#1.rule#i.voterule i.voterule if part <= 3, cluster(biggroup)
xtreg contribute 1.gender 1.rule#i.voterule 1.gender#1.rule#i.voterule i.voterule##i.period if part <= 3, cluster(biggroup) fe

// *** Figure 6 ***
clear all
set memory 100M
use PGvotecompete, clear
keep if thisperiod == 1 & vote < .
gen diffexpmy = expmya - expmyb
xi i.part*i.voterule, prefix(I)
replace lottery = 1 - lottery
replace vote = vote - 1
xtprobit vote expprize diffexpmy gender lottery Ipart_2 Ipart_3 Ivoterule_2 IparXvot_2_2 IparXvot_3_2, nolog 
sum gender
replace gender = r(mean)
sum lottery 
replace lottery = r(mean)
sum Ipart_2 
replace Ipart_2 = r(mean)
sum Ipart_3 
replace Ipart_3 = r(mean)
sum Ivoterule_2 
replace Ivoterule_2 = r(mean)
sum IparXvot_2_2 
replace IparXvot_2_2 = r(mean)
sum IparXvot_3_2
replace IparXvot_3_2 = r(mean)
predict prvote, pu0
gen benefit = expprize + 0.5 * diffexpmy
sum benefit, detail
local low = r(p5)
local high = r(p95)
keep if benefit > `low' & benefit < `high'
collapse prvote, by(benefit)
gen implementM = prvote^9 + 9*prvote^8*(1-prvote) + 36*prvote^7*(1-prvote)^2 + 84*prvote^6*(1-prvote)^3 + 126*prvote^5*(1-prvote)^4
gen implementGV = prvote^9 + 9*prvote^8*(1-prvote) + 27*prvote^7*(1-prvote)^2 + 27*prvote^6*(1-prvote)^3
twoway (line prvote benefit, sort lcolor(edkblue) lwidth(thick) lpattern(-##)) (line implementM benefit, sort lcolor("80 0 0") lwidth(thick)) (line implementGV benefit, sort lcolor(erose) lwidth(thick)), ytitle(Probability, size(medlarge)) yscale(noline) ylabel(0(0.2)1, labsize(medium) angle(horizontal) format(%9.1f) nogrid) xtitle("Expected earnings increase from competition", size(large) margin(top_bottom)) xscale(noline) xlabel(-5(5)15, labsize(medium)) legend(order(1 "Voting in favour of competition" 0 " ") symxsize(12) cols(1) size(large) region(fcolor(white) margin(zero) lcolor(white)) bmargin(tiny) position(5)) name(expbenefit, replace) xsize(5) ysize(5) graphregion(margin(right) fcolor(white) lcolor(white)) plotregion(margin(small) lcolor(black)) nodraw
use PGvotecompete, clear
keep if thisperiod == 1 & vote < .
gen diffexpmy = expmya - expmyb
gen benefit = expprize + 0.5 * diffexpmy
xi i.part*i.voterule, prefix(I)
replace lottery = 1 - lottery
replace vote = vote - 1
xtprobit vote expprize diffexpmy gender lottery Ipart_2 Ipart_3 Ivoterule_2 IparXvot_2_2 IparXvot_3_2, nolog 
predict prvote, pu0
sum prvote if gender==1 
local probw = r(mean)
sum prvote if gender==0
local probm = r(mean)
collapse prvote, by(benefit)
forvalues w=0(1)9 {
	// local w = 0
	clear
	set obs 1000000
	forvalues s=1(1)9 {
		gen vote`s' = runiform() <= cond( `s' <= `w', `probw', `probm')
	}
	gen voteavg = (vote1 + vote2 + vote3 + vote4 + vote5 + vote6 + vote7 + vote8 + vote9 ) / 9
	gen implementM = vote1 + vote2 + vote3 + vote4 + vote5 + vote6 + vote7 + vote8 + vote9 >= 5
	gen implementGV = min(vote1 + vote2 + vote3, vote4 + vote5 + vote6, vote7 + vote8 + vote9) >= 2
	collapse voteavg implementM implementGV
	gen fraqw = `w'
	save tmp`w', replace
}
use tmp0, clear
erase tmp0.dta
forvalues w=1(1)9 {
	append using tmp`w'
	erase tmp`w'.dta
}
twoway (line voteavg fraqw, sort lcolor(edkblue) lwidth(thick) lpattern(-##)) (line implementM fraqw, sort lcolor("80 0 0") lwidth(thick)) (line implementGV fraqw, sort lcolor(erose) lwidth(thick)), ytitle(Probability, size(medlarge)) yscale(noline) ylabel(0(0.2)1, labsize(medium) angle(horizontal) format(%9.1f) nogrid) xtitle(Number of women in the organisation, size(large) margin(top_bottom)) xscale(noline) xlabel(0(1)9, labsize(medium)) title("", size(vlarge) color(black)) legend(order(2 "Implementing competition with majority" 3 "Implementing competition with group veto") symxsize(12) cols(1) size(large) region(fcolor(white) margin(zero) lcolor(white)) bmargin(tiny) position(7) span) name(expimplement, replace) xsize(5) ysize(5) graphregion(margin(left) fcolor(white) lcolor(white)) plotregion(margin(small) lcolor(black)) nodraw
graph set window fontface "Times"
graph combine expbenefit expimplement, rows(1) iscale(*1.3) name(voteprob, replace) xsize(10) ysize(5) imargin(0 10 0 0) graphregion(margin(0 0 0 0) fcolor(white) lcolor(white))
graph export voteprob.eps, as(eps) replace  logo(off) cmyk(off) preview(off) fontface(Times)

// *** Updating expectations (Table 4) ***
use PGvotecompete, clear
gen contmyother = (sumcontribute - contribute)/2
gen cont1 = contribute if rule==1
gen cont0 = contribute if rule==0
gen contmy1 = contmyother if rule==1
gen contmy0 = contmyother if rule==0
egen sumcontbig = sum(contribute), by(period biggroup)
gen contother = (sumcontbig - sumcontribute)/6
gen contother1 = contother if rule==1
gen contother0 = contother if rule==0
collapse gender lottery win cont* exp* rank vote rule treatment, by(biggroup smallgroup subject part voterule)
xtset subject part
gen Dexpprize = F.expprize - expprize
gen Fexpprize = F.expprize
gen tmp = 10 * (2 - rank) - expprize
egen dprize = std(tmp)
gen diffexp = expmya - expmyb
gen Ddiffexpmy = F.diffexp - diffexp
gen Fdiffexpmy = F.diffexp
gen DexpmyC = F.expmya - expmya
gen DexpmyNC = F.expmyb - expmyb
gen FexpmyC = F.expmya
gen FexpmyNC = F.expmyb
replace tmp = contmyother - expmya
egen dcexC = std(tmp)
replace tmp = contmyother - expmyb
egen dcexNC = std(tmp) 

xtreg FexpmyNC i.rule#c.dcexC i.rule#c.dcexNC i.rule i.part#i.voterule, cluster(biggroup) fe
xtreg FexpmyC i.rule#c.dcexC i.rule#c.dcexNC i.rule i.part#i.voterule, cluster(biggroup) fe
xtreg Fdiffexpmy i.rule#c.dcexC i.rule#c.dcexNC i.rule i.part#i.voterule, cluster(biggroup) fe
xtreg Fexpprize i.rule#c.dprize i.rule i.part#i.voterule, cluster(biggroup) fe

// Table A6 (and footnote 33)
gen Lrule = L.rule
gen Ldprize = L.dprize
gen LdcexC = L.dcexC
gen LdcexNC = L.dcexNC

reg Ddiffexpmy i.rule#c.dcexC i.Lrule#c.LdcexC i.rule#c.dcexNC i.Lrule#c.LdcexNC i.rule i.Lrule i.voterule if part==2, cluster(biggroup)
test 1.rule#c.dcexC = 0.rule#c.dcexC
test 1.rule#c.dcexNC = 0.rule#c.dcexNC
test 1.Lrule 0.Lrule#c.LdcexC 1.Lrule#c.LdcexC 0.Lrule#c.LdcexNC 1.Lrule#c.LdcexNC

reg Dexpprize i.rule#c.dprize i.Lrule#c.Ldprize i.rule i.Lrule i.voterule if part==2, cluster(biggroup)
test 1.rule#c.dprize = 0.rule#c.dprize
test 1.Lrule 0.Lrule#c.Ldprize 1.Lrule#c.Ldprize

gen benefit = expprize + 0.5 * diffexp
gen Fbenefit = F.benefit
xtreg Fbenefit i.rule#c.dcexC i.rule#c.dcexNC i.rule#c.dprize i.rule i.part#i.voterule, cluster(biggroup) fe

// Robustness check for exogeneity of risk aversion variable (footnote 12)
use PGvotecompete, clear
egen meanlottery = mean(lottery), by(smallgroup period)
gen lotteryother = 3 * meanlottery - lottery
egen meanearn = mean(earnings), by(smallgroup period)
gen earnother = 3 * meanearn - earnings
egen meancont = mean(contribute), by(smallgroup period)
gen contother = 3 * meancont - contribute
collapse lottery lotteryother earnings earnother contribute contother, by(biggroup smallgroup subject)
pwcorr lottery lotteryother, sig obs
pwcorr contribute contother, sig obs
pwcorr earnings earnother, sig obs

